diff --git a/src/main/java/org/codelibs/fess/app/web/admin/wizard/AdminWizardAction.java b/src/main/java/org/codelibs/fess/app/web/admin/wizard/AdminWizardAction.java
index 09f7a90984fc1a161b302aaeb228af206bfc053c..c61897b501e562b6836e2800d6b7831f42f8fd2a 100644
--- a/src/main/java/org/codelibs/fess/app/web/admin/wizard/AdminWizardAction.java
+++ b/src/main/java/org/codelibs/fess/app/web/admin/wizard/AdminWizardAction.java
@@ -253,7 +253,7 @@ public class AdminWizardAction extends FessAdminAction {
 
     protected String convertCrawlingPath(final String path) {
         if (path.startsWith("http:") || path.startsWith("https:") || path.startsWith("smb:") || path.startsWith("smb1:")
-                || path.startsWith("ftp:")) {
+                || path.startsWith("ftp:") || path.startsWith("storage:")) {
             return path;
         }
 
diff --git a/src/main/java/org/codelibs/fess/app/web/go/GoAction.java b/src/main/java/org/codelibs/fess/app/web/go/GoAction.java
index a3f22ff48e0aa760ebdee12d91822cf4e2824bd4..8b18c88bb714a84aed6ff14933ada18c45af098e 100644
--- a/src/main/java/org/codelibs/fess/app/web/go/GoAction.java
+++ b/src/main/java/org/codelibs/fess/app/web/go/GoAction.java
@@ -153,6 +153,7 @@ public class GoAction extends FessSearchAction {
     }
 
     protected boolean isFileSystemPath(final String url) {
-        return url.startsWith("file:") || url.startsWith("smb:") || url.startsWith("smb1:") || url.startsWith("ftp:");
+        return url.startsWith("file:") || url.startsWith("smb:") || url.startsWith("smb1:") || url.startsWith("ftp:")
+                || url.startsWith("storage:");
     }
 }
diff --git a/src/main/java/org/codelibs/fess/util/GsaConfigParser.java b/src/main/java/org/codelibs/fess/util/GsaConfigParser.java
index 1dfb709c5fb24f947fc48eff613494c977e75411..04c29be548dd792f6d7d6541119836610d1162e3 100644
--- a/src/main/java/org/codelibs/fess/util/GsaConfigParser.java
+++ b/src/main/java/org/codelibs/fess/util/GsaConfigParser.java
@@ -70,7 +70,7 @@ public class GsaConfigParser extends DefaultHandler {
 
     protected String[] webProtocols = new String[] { "http:", "https:" };
 
-    protected String[] fileProtocols = new String[] { "file:", "smb:", "smb1:", "ftp:" };
+    protected String[] fileProtocols = new String[] { "file:", "smb:", "smb1:", "ftp:", "storage:" };
 
     protected LinkedList<String> tagQueue;
 
diff --git a/src/main/resources/fess_config.properties b/src/main/resources/fess_config.properties
index 36e273c0c96ddd405be04bafacf2eb405b1d6a90..37d5f4699a7e1082c8fbc1f3156c161a63e14776 100644
--- a/src/main/resources/fess_config.properties
+++ b/src/main/resources/fess_config.properties
@@ -194,7 +194,7 @@ crawler.document.space.chars=u0009u000Au000Bu000Cu000Du001Cu001Du001Eu001Fu0020u
 crawler.document.fullstop.chars=u002eu06d4u2e3cu3002
 crawler.crawling.data.encoding=UTF-8
 crawler.web.protocols=http,https
-crawler.file.protocols=file,smb,smb1,ftp
+crawler.file.protocols=file,smb,smb1,ftp,storage
 crawler.ignore.robots.txt=false
 crawler.ignore.robots.tags=false
 crawler.ignore.content.exception=true
diff --git a/src/main/java/org/codelibs/fess/mylasta/direction/FessConfig.java b/src/main/java/org/codelibs/fess/mylasta/direction/FessConfig.java
index f3786992cba4a99b68dab6bd3f6d386a4958a615..00b0f1e4e62fcef7252a601d08c0d1da1aef254a 100644
--- a/src/main/java/org/codelibs/fess/mylasta/direction/FessConfig.java
+++ b/src/main/java/org/codelibs/fess/mylasta/direction/FessConfig.java
@@ -298,7 +298,7 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
     /** The key of the configuration. e.g. http,https */
     String CRAWLER_WEB_PROTOCOLS = "crawler.web.protocols";
 
     /** The key of the configuration. e.g. file,smb,smb1,ftp */
     String CRAWLER_FILE_PROTOCOLS = "crawler.file.protocols";
 
     /** The key of the configuration. e.g. false */
@@ -2291,7 +2291,7 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
 
     /**
      * Get the value for the key 'crawler.file.protocols'. <br>
      * The value is, e.g. file,smb,smb1,ftp <br>
      * @return The value of found property. (NotNull: if not found, exception but basically no way)
      */
     String getCrawlerFileProtocols();
@@ -8982,7 +8982,7 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
             defaultMap.put(FessConfig.CRAWLER_DOCUMENT_FULLSTOP_CHARS, "u002eu06d4u2e3cu3002");
             defaultMap.put(FessConfig.CRAWLER_CRAWLING_DATA_ENCODING, "UTF-8");
             defaultMap.put(FessConfig.CRAWLER_WEB_PROTOCOLS, "http,https");
-            defaultMap.put(FessConfig.CRAWLER_FILE_PROTOCOLS, "file,smb,smb1,ftp");
+            defaultMap.put(FessConfig.CRAWLER_FILE_PROTOCOLS, "file,smb,smb1,ftp,storage");
             defaultMap.put(FessConfig.CRAWLER_IGNORE_ROBOTS_TXT, "false");
             defaultMap.put(FessConfig.CRAWLER_IGNORE_ROBOTS_TAGS, "false");
             defaultMap.put(FessConfig.CRAWLER_IGNORE_CONTENT_EXCEPTION, "true");
@@ -298,7 +298,7 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
     String CRAWLER_WEB_PROTOCOLS = "crawler.web.protocols";
 
-    /** The key of the configuration. e.g. file,smb,smb1,ftp */
+    /** The key of the configuration. e.g. file,smb,smb1,ftp,storage */
     String CRAWLER_FILE_PROTOCOLS = "crawler.file.protocols";
 
@@ -2291,7 +2291,7 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
     /**
      * Get the value for the key 'crawler.file.protocols'. <br>
-     * The value is, e.g. file,smb,smb1,ftp <br>
+     * The value is, e.g. file,smb,smb1,ftp,storage <br>
      * @return The value of found property. (NotNull: if not found, exception but basically no way)
      */